@@ -45,7 +45,9 @@ agentUDPv6Endpoint = None
 agentUNIXEndpoint = None
 startOID = univ.ObjectIdentifier('1.3.6')
 stopOID = None
-outputFile = sys.stderr
+outputFile = sys.stdout
+if hasattr(outputFile, 'buffer'):
+    outputFile = outputFile.buffer
 variationModuleOptions = ""
 variationModuleName = variationModule = None
 
@@ -70,7 +72,7 @@ Usage: %s [--help]
     [--version]
     [--debug=<%s>]
     [--logging-method=<stdout|stderr|syslog|file>[:args>]]
-    [--version=<1|2c|3>]
+    [--protocol-version=<1|2c|3>]
     [--community=<string>]
     [--v3-user=<username>]
     [--v3-auth-key=<key>]
@@ -94,12 +96,20 @@ Usage: %s [--help]
         '|'.join([ x for x in privProtocols if x != 'NONE' ])
     )
 
-log.setLogger('snmprec', 'stdout')
+log.setLogger('snmprec', 'stderr')
 
 try:
-    opts, params = getopt.getopt(sys.argv[1:], 'hv',
-        ['help', 'version', 'debug=', 'logging-method=', 'quiet', 'v1', 'v2c', 'v3', 'version=', 'community=', 'v3-user=', 'v3-auth-key=', 'v3-priv-key=', 'v3-auth-proto=', 'v3-priv-proto=', 'context=', 'use-getbulk', 'getbulk-repetitions=', 'agent-address=', 'agent-port=', 'agent-udpv4-endpoint=', 'agent-udpv6-endpoint=', 'agent-unix-endpoint=', 'start-oid=', 'stop-oid=', 'output-file=', 'variation-modules-dir=', 'variation-module=', 'variation-module-options=']
-        )
+    opts, params = getopt.getopt(sys.argv[1:], 'hv', [
+        'help', 'version', 'debug=', 'logging-method=', 'quiet',
+        'v1', 'v2c', 'v3', 'protocol-version=', 'community=', 
+        'v3-user=', 'v3-auth-key=', 'v3-priv-key=', 'v3-auth-proto=',
+        'v3-priv-proto=', 'context=', 'use-getbulk', 'getbulk-repetitions=',
+        'agent-address=', 'agent-port=', 'agent-udpv4-endpoint=',
+        'agent-udpv6-endpoint=', 'agent-unix-endpoint=', 
+        'start-oid=', 'stop-oid=', 'output-file=',
+        'variation-modules-dir=', 'variation-module=',
+        'variation-module-options='
+    ] )
 except Exception:
     sys.stderr.write('ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
     sys.exit(-1)
@@ -125,9 +135,10 @@ Documentation:
         sys.stderr.write("""\
 SNMP Simulator version %s, written by Ilya Etingof <ilya@glas.net>
 Using foundation libraries: pysnmp %s, pyasn1 %s.
+Python interpreter: %s
 Software documentation and support at http://snmpsim.sf.net
 %s
-""" % (snmpsim.__version__, hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown', hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown', helpMessage))
+""" % (snmpsim.__version__, hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown', hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown', sys.version, helpMessage))
         sys.exit(-1)
     elif opt[0] == '--debug':
         debug.setLogger(debug.Debug(opt[1]))
@@ -145,7 +156,7 @@ Software documentation and support at http://snmpsim.sf.net
         snmpVersion = 1
     elif opt[0] == '--v3':
         snmpVersion = 3
-    elif opt[0] == '--version':
+    elif opt[0] == '--protocol-version':
         if opt[1] in ('1', 'v1'):
             snmpVersion = 0
         elif opt[1] in ('2', '2c', 'v2c'):
@@ -282,12 +293,12 @@ if variationModuleName:
     for variationModulesDir in confdir.variation:
         log.msg('Scanning "%s" directory for variation modules...' % variationModulesDir)
         if not os.path.exists(variationModulesDir):
-            log.msg('Directory %s does not exist' % variationModulesDir)
+            log.msg('Directory "%s" does not exist' % variationModulesDir)
             continue
 
         mod = os.path.join(variationModulesDir, variationModuleName + '.py')
         if not os.path.exists(mod):
-            log.msg('Module %s not found' % mod)
+            log.msg('Variation module "%s" not found' % mod)
             continue
 
         ctx = { 'path': mod, 'moduleContext': {} }
@@ -298,14 +309,14 @@ if variationModuleName:
             else:
                 execfile(mod, ctx)
         except Exception:
-            log.msg('Variation module %s execution failure: %s' %  (mod, sys.exc_info()[1]))
+            log.msg('Variation module "%s" execution failure: %s' %  (mod, sys.exc_info()[1]))
             sys.exit(-1)
         else:
             variationModule = ctx
-            log.msg('Module %s loaded' % variationModuleName)
+            log.msg('Variation module "%s" loaded' % variationModuleName)
             break
     else:
-        log.msg('ERROR: variation module %s not found' % variationModuleName)
+        log.msg('ERROR: variation module "%s" not found' % variationModuleName)
         sys.exit(-1)
        
 # SNMP configuration
@@ -372,18 +383,18 @@ if variationModule:
     log.msg('Initializing variation module...')
     for x in ('init', 'record', 'shutdown'):
         if x not in variationModule:
-            log.msg('ERROR: missing %s handler at module %s' % (x, variationModuleName))
+            log.msg('ERROR: missing "%s" handler at variation module "%s"' % (x, variationModuleName))
             sys.exit(-1)
     try:
-        variationModule['init'](snmpEngine,
+        variationModule['init'](snmpEngine=snmpEngine,
                                 options=variationModuleOptions,
                                 mode='recording',
                                 startOID=startOID,
                                 stopOID=stopOID)
     except Exception:
-        log.msg('Module %s initialization FAILED: %s' % (variationModuleName, sys.exc_info()[1]))
+        log.msg('Variation module "%s" initialization FAILED: %s' % (variationModuleName, sys.exc_info()[1]))
     else:
-        log.msg('Module %s initialization OK' % variationModuleName)
+        log.msg('Variation module "%s" initialization OK' % variationModuleName)
 
 # Data file builder
 
@@ -459,9 +470,14 @@ def cbFun(sendRequestHandle, errorIndication, errorStatus, errorIndex,
             try:
                 line = dataFileHandler.format(oid, val, **context)
             except error.MoreDataNotification:
-                cbCtx['total'] += cbCtx['count']
                 cbCtx['count'] = 0
                 cbCtx['iteration'] += 1
+
+                moreDataNotification = sys.exc_info()[1]
+                if 'period' in moreDataNotification:
+                    log.msg('%s OIDs dumped, waiting %.2f sec(s)...' % (cbCtx['total'], moreDataNotification['period']))
+                    time.sleep(moreDataNotification['period'])
+ 
                 # initiate another SNMP walk iteration
                 if getBulkFlag:
                     cmdGen.sendReq(
@@ -477,10 +493,14 @@ def cbFun(sendRequestHandle, errorIndication, errorStatus, errorIndex,
  
             except error.NoDataNotification:
                 pass
+            except error.SnmpsimError:
+                log.msg('ERROR: %s' % (sys.exc_info()[1],))
+                continue
             else:
                 outputFile.write(line)
 
             cbCtx['count'] += 1
+            cbCtx['total'] += 1
 
             if cbCtx['count'] % 100 == 0:
                 log.msg('OIDs dumped: %s/%s' % (cbCtx['iteration'], cbCtx['count']))
@@ -531,7 +551,7 @@ except Exception:
 if variationModule:
     log.msg('Shutting down variation module %s...' % variationModuleName)
     try:
-        variationModule['shutdown'](snmpEngine,
+        variationModule['shutdown'](snmpEngine=snmpEngine,
                                     options=variationModuleOptions,
                                     mode='recording')
     except Exception:
@@ -550,3 +570,6 @@ log.msg('OIDs dumped: %s, elapsed: %.2f sec, rate: %.2f OIDs/sec' % (cbCtx['tota
 if exc_info:
     for line in traceback.format_exception(*exc_info):
         log.msg(line.replace('\n', ';'))
+
+outputFile.flush()
+outputFile.close()
