@@ -1,5 +1,6 @@
 from snmpsim.record import dump
 from snmpsim.grammar import snmprec
+from snmpsim import error
 
 class SnmprecRecord(dump.DumpRecord):
     grammar = snmprec.SnmprecGrammar()
@@ -12,10 +13,13 @@ class SnmprecRecord(dump.DumpRecord):
         else:
             hexvalue = None
 
-        if hexvalue is None:
-            return oid, tag, self.grammar.tagMap[tag](value)
-        else:
-            return oid, tag, self.grammar.tagMap[tag](hexValue=hexvalue)
+        try:
+            if hexvalue is None:
+                return oid, tag, self.grammar.tagMap[tag](value)
+            else:
+                return oid, tag, self.grammar.tagMap[tag](hexValue=hexvalue)
+        except:
+            raise error.SnmpsimError('value evaluation error for tag %r, value %r' % (tag, value))
 
     def formatValue(self, oid, value, **context):
         if 'nohex' in context and context['nohex']:
