@@ -14,7 +14,7 @@ from snmpsim import confdir
 from snmpsim import log
 from snmpsim import error
 
-def init(snmpEngine, **context):
+def init(**context):
     if context['options']:
         for k,v in [x.split(':') for x in context['options'].split(',')]:
             if k == 'addon':
@@ -183,13 +183,12 @@ def record(oid, tag, value, **context):
         else:
             moduleContext['filenum'] = 0
         if 'iterations' in moduleContext and moduleContext['iterations']:
-            wait = max(0, moduleContext['period'] - (time.time() - moduleContext['started']))
-            log.msg('multiplex: waiting %.2f sec(s), %s OIDs dumped, %s iterations remaining...' % (wait, context['total']+context['count'], moduleContext['iterations']))
-            time.sleep(wait)
+            log.msg('multiplex: %s iterations remaining' % moduleContext['iterations'])
             moduleContext['started'] = time.time()
             moduleContext['iterations'] -= 1
             moduleContext['filenum'] += 1
-            raise error.MoreDataNotification()
+            wait = max(0, moduleContext['period'] - (time.time() - moduleContext['started']))
+            raise error.MoreDataNotification(period=wait)
         else:
             raise error.NoDataNotification()
 
@@ -206,7 +205,7 @@ def record(oid, tag, value, **context):
         SnmprecRecord().format(context['origOid'], context['origValue'])
     )
 
-    if not context['count']:
+    if not context['total']:
         settings = {
             'dir': moduleContext['dir'].replace(os.path.sep, '/')
         }
@@ -221,4 +220,4 @@ def record(oid, tag, value, **context):
     else:
         raise error.NoDataNotification()
 
-def shutdown(snmpEngine, **context): pass
+def shutdown(**context): pass
